{ config, pkgs, ... }:

{
  environment.systemPackages = with pkgs.haskellPackages; with pkgs; [
    gitg
    gmpc
    m4
    subversion
    openjdk8
    sbt scala
    stable.chromium
    qalculate-gtk
    speedcrunch
    viewnior
    gnupg
    pass xclip pwgen
    remmina
    ledger
    hledger
    hledger-diff
    cmake ninja
    mpv
    stable.wireshark-gtk
    neomutt notmuch
    stable.goldendict
    patchelf
    bazaar
    tokei loc
    ripgrep
    imagemagick
    mercurial

    androidenv.platformTools # adb & fastboot

    lm_sensors
    hdparm
    lsof

    pdfpc

    # haskell dev
    cabal2nix
    cabal-install
    # ghc-mod

    # emacs
    emacs
    emacsPackages.cask
    ghostscript # for auctex
    aspell

    nodejs

    mediainfo

    isync
    mu
    msmtp
    vdirsyncer khard khal

    linuxPackages.perf

    veriT
    minisat
    picosat
    glucose
    prover9
    eprover
    metis-prover
    spass
    z3
    stable.cvc4
    graphviz
    # toysolver
    oldstable.haskellPackages.tip-lib

    emacsPackages.proofgeneral

    oldstablePkgs # protect nixpkgs checkout from GC
    stablePkgs
  ] ++ (with aspellDicts; [ en de fr nl ]);

  nixpkgs.config.packageOverrides = pkgs: with pkgs; let
    fetchNixPkgs = { rev, sha256 }:
    fetchFromGitHub {
      inherit sha256 rev;
      owner = "NixOS";
      repo = "nixpkgs-channels";
    };
    oldstablePkgs = fetchNixPkgs {
      rev = "5237768d62a40236d24fafbd9f4f97f3227399ce";
      sha256 = "1j707pwm6ll2cvmqvwfxxq21gd9q7l6s3vi3vc01jklplj2v20is";
    };
    stablePkgs = fetchNixPkgs {
      rev = "19879836d10f64a10658d1e2a84fc54b090e2087";
      sha256 = "1x41ch2mgzs85ivvyp3zqkbh4i0winjg69g5x0p3q7avgrhkl7ph";
    };
  in {
    # idea-community-eap = pkgs.idea.idea-community.overrideDerivation (oldAttrs: rec {
    #     name = "idea-community-${version}";
    #     version = "2017.2.eap";
    #     src = pkgs.fetchurl {
    #       url = "https://download.jetbrains.com/idea/ideaIC-172.3544.6-no-jdk.tar.gz";
    #       sha256 = "72874a0393a6388b04353a359eea1d1242f59d6e7b96a4cf43c793602ac7ccdb";
    #     };
    #   });
    idea-community-eap = pkgs.idea.idea-community;

    # clion-eap = pkgs.idea.clion.overrideDerivation (oldAttrs: rec {
    #   name = "clion-${version}";
    #   version = "2017.1.eap";
    #   src = pkgs.fetchurl {
    #     url = "http://download.jetbrains.com/cpp/CLion-2017.1-RC.tar.gz";
    #     sha256 = "1rv9rcjv4kv39l9r4g5kqbd4y175301a6kr3js3szkjmhqd50qq3";
    #   };
    # });
    clion-eap = pkgs.idea.clion;

    # neovim = pkgs.neovim.override {
    #   extraPythonPackages = [ pkgs.pythonPackages.websocket_client ];
    # };

    oldstablePkgs = oldstablePkgs;
    oldstable = import oldstablePkgs {};
    stablePkgs = stablePkgs;
    stable = import stablePkgs {};

    qutebrowser = pkgs.qutebrowser.override { withWebEngineDefault = true; };
  };

  nixpkgs.config.allowTexliveBuilds = true;
  nixpkgs.config.allowUnfree = true;

}
